# pacotepypi

**packpypi** é um simples pacote para administrar os dados cadastrados, armazenados e consultados dos usuarios.

## Dependências
**Python 3.6** ou posterior


## Começando o uso
É necessário que você instale o pacote **packpypi**, para isso basta executar:
```
pip install packpypi
```

## Função

* `interacao ()` - Registra o cpf, endereço e nome do usuário
* `armazenamento ()` - Salva as informações do usuário em um arquivo de texto
* `consulta ()` - Realiza a consulta dos dados do cpf informado através do arquivo de texto



